==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/CallGraph__24TargetsOfUnitIterator.h <==
// class soot.jimple.toolkits.callgraph.CallGraph$TargetsOfUnitIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee664d8fe3c897e4 soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$_init$1ba818d2319a0b1d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*position;
	struct _jc_object	*u;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/CallGraph__24TargetsOfUnitIterator.h <==
// class soot.jimple.toolkits.callgraph.CallGraph$TargetsOfUnitIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ee664d8fe3c897e4 soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$_init$1ba818d2319a0b1d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vmethods	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*position;
	struct _jc_object	*u;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_refs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$vtype _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfUnitIterator_H_ */
